# AUTOGENERATED! DO NOT EDIT! File to edit: nbs/utils.ipynb

__all__ = ['calculate_area', 'format_name']

def format_name(first: str, last: str) -> str:
    """Format a full name from first and last name."""
    return f"{first} {last}"

def calculate_area(width: float, height: float) -> float:
    """Calculate area of a rectangle."""
    return width * height
