# AUTOGENERATED! DO NOT EDIT! File to edit: nbs/core.ipynb

__all__ = ['VERSION', 'get_version']

# %% nbs/core.ipynb 2
VERSION = "1.0.0"

# %% nbs/core.ipynb 3
def get_version() -> str:
    """Get the version."""
    return VERSION
