# AUTOGENERATED! DO NOT EDIT! File to edit: nbs/utils.ipynb

__all__ = ['DEFAULT_NAME', 'PI', 'calculate_area', 'greet']

# %% nbs/utils.ipynb 0
"""Utility functions module.

This is an example module that will be converted to a notebook.
"""


def greet(name: str) -> str:
    """Greet someone by name.

    Args:
        name: The name to greet.

    Returns:
        A greeting string.
    """
    return f"Hello, {name}!"


def calculate_area(width: float, height: float) -> float:
    """Calculate the area of a rectangle.

    Args:
        width: The width of the rectangle.
        height: The height of the rectangle.

    Returns:
        The area.
    """
    return width * height


# Constants
DEFAULT_NAME = "World"
PI = 3.14159
