# AUTOGENERATED! DO NOT EDIT! File to edit: nbs/my_script.ipynb

__all__ = ['main']

# %% nbs/my_script.ipynb 2
def main():
    """Main entry point."""
    print("Hello from my_script!")
    return 0
