# AUTOGENERATED! DO NOT EDIT! File to edit: nbs/01_export_basics.ipynb

__all__ = ['PUBLIC_CONSTANT', 'public_function', 'use_internal']

# %% nbs/01_export_basics.ipynb 3
def public_function():
    """This function is exported and included in __all__."""
    return "I'm public!"

# %% nbs/01_export_basics.ipynb 4
PUBLIC_CONSTANT = 42

# %% nbs/01_export_basics.ipynb 6
def internal_helper():
    """This function is exported but NOT in __all__.

    It can still be imported directly:
        from .export_basics import internal_helper

    But won't be included in:
        from .export_basics import *
    """
    return "I'm internal!"

# %% nbs/01_export_basics.ipynb 7
def use_internal():
    """Public function that uses the internal helper."""
    return internal_helper()
