"""
Synchronization utilities for nblite.

This module handles:
- Twin file management
- Lineage tracking between notebooks and modules
"""

# Exports will be added as classes are implemented
# from nblite.sync.twins import get_twins
# from nblite.sync.lineage import NotebookLineage

__all__: list[str] = []
