# AUTOGENERATED! DO NOT EDIT!

def my_decorator(func):
    return func

DEFAULT_MULTIPLIER = 2

@my_decorator
def process_data(
    input_list: list,
    multiplier: int = 2
) -> list:
    """Process a list of numbers.

    Args:
        input_list: List of numbers to process
        multiplier: Value to multiply each number by

    Returns:
        Processed list of numbers
    """
    # Validate input
    if not isinstance(input_list, list):
        raise TypeError("input_list must be a list")
    # Process the data
    result = [x * multiplier for x in input_list]
    return result
    return result
